@@ -32,7 +32,7 @@ __all__ = [
 
 __author__ = "Julien Moura"
 __copyright__ = "2020 - {0}, {1}".format(date.today().year, __author__)
-__email__ = "ingeoveritas@protonmail.com"
+__email__ = "dev@ingeoveritas.com"
 __executable_name__ = "MkDocsRssPlugin.exe"
 __license__ = "GNU General Public License v3.0"
 __summary__ = "Generates a static RSS feed using git log."
@@ -40,7 +40,7 @@ __title__ = "MkDocs RSS plugin"
 __title_clean__ = "".join(e for e in __title__ if e.isalnum())
 __uri__ = "https://github.com/Guts/mkdocs-rss-plugin/"
 
-__version__ = "0.3.0"
+__version__ = "0.5.0"
 __version_info__ = tuple(
     [
         int(num) if num.isdigit() else num
